# core-image-builder
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import argparse
import configparser
import logging
import os

from uservice_utils.logging import configure_service_logging
from uservice_utils.queue import (
    SimpleRabbitQueueWorker,
    DefaultRetryPolicy,
)

from core_image_builder.queue import (
    create_connection_from_config,
    CoreImageResultBuilder,
)
from core_image_builder import (
    constants,
    worker,
)


def read_config():
    parser = argparse.ArgumentParser(description='Core image builder.')
    parser.add_argument(
        '-c',
        '--conf',
        default='core-service.conf',
        help='Configuration file path'
    )
    args = parser.parse_args()

    # Load configuration options.
    config = configparser.ConfigParser()
    config.read(args.conf)
    return config


def main():
    config = read_config()
    log_path = os.path.abspath(
        os.path.join(__file__, '../../logs/core-image-builder.log')
    )
    configure_service_logging(
        log_path,
        config['logstash'] if 'logstash' in config else None
    )
    logger = logging.getLogger(__name__)
    logger.info('Started!', extra=constants.LOGGING_EXTRA)

    connection = create_connection_from_config(config)
    try:
        with connection:
            builder = CoreImageResultBuilder(connection)
            retry_policy = DefaultRetryPolicy(
                max_retries=3,
                dead_queue='core.deadletters.{}'.format(constants.API_VERSION)
            )
            monitor = SimpleRabbitQueueWorker(
                connection,
                'core.image.{}'.format(constants.API_VERSION),
                worker.ImageBuilderWorker(config, builder),
                retry_policy,
            )
            monitor.run()
    except KeyboardInterrupt:
        print("Bye!")
