# core-image-builder
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import kombu

from core_image_builder import constants

logger = logging.getLogger(__name__)

__all__ = [
    'CoreImageResultBuilder',
    'create_connection_from_config',
]


def create_connection_from_config(config):
    """Create a connection given a config object.

    'config' can either be a ConfigParser instance, or a nested dictionary.

    """
    amqp_uris = config.get('amqp', 'uris').split()
    return kombu.Connection(amqp_uris)


class CoreImageResultBuilder(object):

    """A callable that knows how to publish results from this service.

    For now we're using a simple queue, but this can easily be extended to use
    a full-blown topic exchange in the future.

    """

    def __init__(self, connection):
        self.connection = connection

    def __call__(self, payload):
        """Take 'payload' and enqueue it on the rabbit queue."""
        queue = self.connection.SimpleQueue(
            "core.tests.{}".format(constants.API_VERSION)
        )
        queue.put(payload)
        queue.close()
